@@ -18,6 +18,10 @@
 #' @template spq-params
 #' @param metric Character string containing the name of the metric,
 #' e.g. "Collaboration_hours"
+#'
+#' @param ncol Numeric value setting the number of columns on the plot. Defaults
+#'   to `NULL` (automatic).
+#'
 #' @param return String specifying what to return. This must be one of the following strings:
 #'   - `"plot"`
 #'   - `"table"`
@@ -41,6 +45,14 @@
 #' # Return plot of Collaboration Hours
 #' sq_data %>% create_line(metric = "Collaboration_hours", return = "plot")
 #'
+#' # Return plot but coerce plot to two columns
+#' sq_data %>%
+#'   create_line(
+#'     metric = "Collaboration_hours",
+#'     hrvar = "Organization",
+#'     ncol = 2
+#'     )
+#'
 #' # Return plot of Work week span and cut by `LevelDesignation`
 #' sq_data %>% create_line(metric = "Workweek_span", hrvar = "LevelDesignation")
 #'
@@ -54,6 +66,7 @@ create_line <- function(data,
                         metric,
                         hrvar = "Organization",
                         mingroup = 5,
+                        ncol = NULL,
                         return = "plot"){
 
   ## Check inputs
@@ -110,7 +123,7 @@ create_line <- function(data,
     myTable_plot %>%
       ggplot(aes(x = Date, y = !!sym(metric))) +
       geom_line(colour = "#1d627e") +
-      facet_wrap(.~group) +
+      facet_wrap(.~group, ncol = ncol) +
       scale_fill_gradient(name="Hours", low = "white", high = "red") +
       theme_wpa_basic() +
       theme(strip.background = element_rect(color = "#1d627e",
